# stores or updates user preferences 

from portalDb import db
so=Session()
db['users'].update(db['users'][so.user],bgcolor=_bgcolor,fontfamily=_fontfamily)
raise HTTP_REDIRECTION,"index.pih"
